@@ -3,13 +3,14 @@ from __future__ import annotations
 from dataclasses import dataclass, field
 from typing import Any, Union
 
+from requests import Response as StdResponse
 from tls_client.response import Response as TLSResponse
 
 
 # Dataclass needs to be here to avoid circular imports
 @dataclass
 class Response:
-    raw: TLSResponse
+    raw: TLSResponse | StdResponse
     status_code: int
     response: Any
 
